@@ -17,6 +17,8 @@
 #include <KCrash>
 #include <KAboutData>
 
+#include <mprisplugin.h>
+
 #include "clipboard.h"
 #include "searchmodel.h"
 #include "albummodel.h"
@@ -31,8 +33,9 @@
 #include "blur.h"
 #include "localplaylistmodel.h"
 #include "localplaylistsmodel.h"
+#include "playlistimporter.h"
 
-#include "asyncdatabase.h"
+#include <ThreadedDatabase>
 
 constexpr auto URI = "org.kde.ytmusic";
 
@@ -67,7 +70,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setOrganizationDomain("kde.org");
     about.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=audiotube");
     auto future = YTMusicThread::instance()->version();
-    connectFuture(future, &app, [&about](const auto &version) {
+    QCoro::connect(std::move(future), &app, [&about](const auto &version) {
         about.addComponent(QStringLiteral("ytmusicapi"), i18n("Unofficial API for YouTube Music"), version);
         KAboutData::setApplicationData(about);
     });
@@ -78,6 +81,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     QQmlApplicationEngine engine;
 
+    MprisPlugin(&engine).registerTypes("org.nemomobile.qtmpris");
+
     qmlRegisterType<SearchModel>(URI, 1, 0, "SearchModel");
     qmlRegisterType<AlbumModel>(URI, 1, 0, "AlbumModel");
     qmlRegisterType<VideoInfoExtractor>(URI, 1, 0, "VideoInfoExtractor");
@@ -88,6 +93,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<Blur>(URI, 1, 0, "Blur");
     qmlRegisterType<LocalPlaylistModel>(URI, 1, 0, "LocalPlaylistModel");
     qmlRegisterType<LocalPlaylistsModel>(URI, 1, 0, "LocalPlaylistsModel");
+    qmlRegisterType<PlaylistImporter>(URI, 1, 0, "PlaylistImporter");
     qmlRegisterSingletonType(URI, 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
         return engine->toScriptValue(KAboutData::applicationData());
     });
